library(testthat)
library(WufooR)
library(httr)
library(jsonlite)
library(dplyr)

# test_check("WufooR")
